# purephotonicscontrol

A python package to easily communicate with PurePhotonics lasers through python. 
Most purephotonics features are implemented, so the user can create their own computer controlled laser sequence.
The package has been developed for the PPCL560 laser, but should generalise.

The code assume that the PPCL560 laser is interfaced with a Teensy 3.6 as outlined in(TO DO!). This interface is useful for creating trigger-able signals from the laser.
When the laser to connected to a PC directly, do this (TO DO!)

## Getting Started

Run the examples on the git
TO DO: Add details on connecting PC to laser

### Prerequisites

Python3, a laser


### Installing


```
pip install purephotonicscontrol
```


TO DO: End with an example of getting some data out of the system or using it for a little demo


## Contributing

TO DO


## Authors

* **Matthew Berrington**  - [bitbucket profile](https://bitbucket.org/matthewberrington)

## License

The MIT License

## Acknowledgments

* Thanks to PurePhotonics for provided a python example which seeded this project



